/*
 * Sixth Data. Copyright ©2012-2019, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 */

package eu.svjatoslav.sixth.data.store;

import java.io.IOException;

/**
 * Data store acts as a numerical ID to corresponding record map.
 * <p>
 * Record is basically an array of bytes of arbitrary length, identifiable by ID
 * that is assigned to record during record creation.
 * <p>
 * Records can be updated with alternative content and length. Data store takes
 * care of data fragmentation.
 */
public interface DataStore {

    /**
     * Close datastore.
     */
    void close() throws IOException;

    /**
     * Create new record and set its initial contents.
     */
    int createRecord(byte[] value) throws IOException;

    /**
     * Delete record identified by given ID. DataStore will mark given ID as
     * unused, and could reuse this ID later for another newly created record.
     */
    void deleteRecord(int id) throws IOException;

    /**
     * Read entire record into byte array.
     */
    byte[] readRecord(int id) throws IOException;

    /**
     * Update record with new value.
     */
    void updateRecord(int id, byte[] value) throws IOException;

}
